@@ -866,12 +866,22 @@ def initialize_config():
     # Make it no longer a proxy variable, just set it to an actual string
     global WEBSERVER_CONFIG
     WEBSERVER_CONFIG = AIRFLOW_HOME + '/webserver_config.py'
-
+    import shutil
     if not os.path.isfile(WEBSERVER_CONFIG):
-        import shutil
-
         log.info('Creating new FAB webserver config file in: %s', WEBSERVER_CONFIG)
         shutil.copy(_default_config_file_path('default_webserver_config.py'), WEBSERVER_CONFIG)
+
+    # smartpip related files
+    COMMON_PATH = os.path.join(AIRFLOW_HOME, 'common')
+    ETL_SCRIPT_PATH = os.path.join(AIRFLOW_HOME, 'etl_script')
+    FUNCTION_CONFIG = os.path.join(COMMON_PATH, 'functions.py')
+    if not os.path.exists(COMMON_PATH):
+        os.mkdir(COMMON_PATH)
+    if not os.path.exists(ETL_SCRIPT_PATH):
+        os.mkdir(ETL_SCRIPT_PATH)
+    if not os.path.isfile(FUNCTION_CONFIG):
+        shutil.copy(_default_config_file_path('default_functions.py'), WEBSERVER_CONFIG)
+
     return conf
 
 
