@@ -1821,7 +1821,7 @@ class TaskInstance(Base, LoggingMixin):
         use_default = not hasattr(self, 'task')
         exception_html = str(exception).replace('\n', '<br>')
 
-        default_subject = 'Airflow alert: {{ti}}'
+        default_subject = 'SmartPip alert: {{ti}}'
         # For reporting purposes, we report based on 1-indexed,
         # not 0-indexed lists (i.e. Try 1 instead of
         # Try 0 for the first attempt).
