@@ -50,7 +50,6 @@ except Exception:
     pass
 log.info("Configured default timezone %s", TIMEZONE)
 
-
 HEADER = '\n'.join(
     [
         r'  ____________       _____________',
@@ -58,6 +57,7 @@ HEADER = '\n'.join(
         r'____  /| |_  /__  ___/_  /_ __  /_  __ \_ | /| / /',
         r'___  ___ |  / _  /   _  __/ _  / / /_/ /_ |/ |/ /',
         r' _/_/  |_/_/  /_/    /_/    /_/  \____/____/|__/',
+        r'smartpip by www.smartchart.cn'
     ]
 )
 
@@ -69,13 +69,17 @@ GUNICORN_WORKER_READY_PREFIX = "[ready] "
 LOG_FORMAT = conf.get('logging', 'log_format')
 SIMPLE_LOG_FORMAT = conf.get('logging', 'simple_log_format')
 
-
 # for smartData
-P_URL = conf.get('core', 'p_url')
+P_URL = conf.get('smartpip', 'p_url')
 # APPKEY for smartdata portal
-APPKEY = conf.get('core', 'appkey')
+APPKEY = conf.get('smartpip', 'appkey')
+DATASET_TOKEN = conf.get('smartpip', 'dataset_token')
+REFRESH_TOKEN = conf.get('smartpip', 'refresh_token')
 # the path to save etl script
-ETL_FILE_PATH = conf.get('core','etl_file_path')
+ETL_FILE_PATH = conf.get('smartpip', 'etl_file_path')
+DATAX_HOME = conf.get('smartpip', 'datax_home')
+KETTLE_HOME = conf.get('smartpip', 'kettle_home')
+HIVE_HOME = conf.get('smartpip', 'hive_home')
 
 SQL_ALCHEMY_CONN: Optional[str] = None
 PLUGINS_FOLDER: Optional[str] = None
@@ -465,7 +469,6 @@ KILOBYTE = 1024
 MEGABYTE = KILOBYTE * KILOBYTE
 WEB_COLORS = {'LIGHTBLUE': '#4d9de0', 'LIGHTORANGE': '#FF9933'}
 
-
 # Updating serialized DAG can not be faster than a minimum interval to reduce database
 # write rate.
 MIN_SERIALIZED_DAG_UPDATE_INTERVAL = conf.getint('core', 'min_serialized_dag_update_interval', fallback=30)
